@@ -1,6 +1,7 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
 import os
+import io
 import sys
 import logging
 
@@ -8,12 +9,15 @@ import pandas as pd
 import ujson as json
 from django.conf import settings
 from django.contrib.auth import logout
-from django.http import HttpResponse, HttpResponseServerError
+from django.http import HttpResponse, HttpResponseServerError, HttpResponseForbidden
 from django.shortcuts import redirect, reverse
 from django.template import loader
+from django.views.static import serve
 from django.http import JsonResponse
+from wsgiref.util import FileWrapper
 
 from core import utils, version
+from core.utils.params import get_bool_env, get_env
 from core.label_config import generate_time_series_json
 from core.utils.common import directory_index, collect_versions
 
@@ -25,7 +29,7 @@ def main(request):
 
     if user.is_authenticated:
 
-        if 'organization_pk' not in request.session:
+        if user.active_organization is None and 'organization_pk' not in request.session:
             logout(request)
             return redirect(reverse('user-login'))
 
@@ -120,3 +124,40 @@ def samples_time_series(request):
     response['Content-Disposition'] = f'attachment; filename="{filename}"'
     response['filename'] = filename
     return response
+
+
+def localfiles_data(request):
+    """Serving files for LocalFilesImportStorage"""
+    path = request.GET.get('d')
+    local_serving_allowed = get_bool_env('LOCAL_FILES_SERVING_ENABLED', default=False)
+    if local_serving_allowed is False:
+        return HttpResponseForbidden("Serving local files can be dangerous, so it's disabled by default. "
+                                     'You can enable it with LOCAL_FILES_SERVING_ENABLED environment variable')
+
+    local_serving_document_root = get_env('LOCAL_FILES_DOCUMENT_ROOT', default='/')
+    if path and request.user.is_authenticated:
+        return serve(request, path, document_root=local_serving_document_root)
+
+    return HttpResponseForbidden()
+
+
+def static_file_with_host_resolver(path_on_disk, content_type):
+    """ Load any file, replace {{HOSTNAME}} => settings.HOSTNAME, send it as http response
+    """
+    path_on_disk = os.path.join(os.path.dirname(__file__), path_on_disk)
+
+    def serve_file(request):
+        with open(path_on_disk, 'r') as f:
+            body = f.read()
+            body = body.replace('{{HOSTNAME}}', settings.HOSTNAME)
+
+            out = io.StringIO()
+            out.write(body)
+            out.seek(0)
+
+            wrapper = FileWrapper(out)
+            response = HttpResponse(wrapper, content_type=content_type)
+            response['Content-Length'] = len(body)
+            return response
+
+    return serve_file
