@@ -5,9 +5,18 @@ from rest_framework import serializers
 
 from tasks.models import Task, Annotation
 from tasks.serializers import PredictionSerializer
+from users.models import User
+
+
+class UserSerializer(serializers.ModelSerializer):
+    class Meta:
+        model = User
+        fields = ['id', 'email', 'first_name', 'last_name']
 
 
 class AnnotationSerializer(serializers.ModelSerializer):
+    completed_by = UserSerializer(read_only=True)
+
     class Meta:
         model = Annotation
         fields = '__all__'
