@@ -74,6 +74,7 @@ class ViewAPI(viewsets.ModelViewSet):
     filter_backends = [DjangoFilterBackend]
     my_tags = ["Data Manager"]
     filterset_fields = ["project"]
+    task_serializer_class = TaskSerializer
 
     def get_permissions(self):
         permission_classes = [IsBusiness]
@@ -99,7 +100,18 @@ class ViewAPI(viewsets.ModelViewSet):
         queryset.all().delete()
         return Response(status=204)
 
-    @swagger_auto_schema(tags=['Data Manager'], responses={200: TaskSerializer(many=True)})
+    @staticmethod
+    def evaluate_predictions(tasks):
+        # call machine learning api and format response
+        for task in tasks:
+            project = task.project
+            if not project.show_collab_predictions:
+                return
+
+            for ml_backend in project.ml_backends.all():
+                ml_backend.predict_one_task(task)
+
+    @swagger_auto_schema(tags=['Data Manager'], responses={200: task_serializer_class(many=True)})
     @action(detail=True, methods=["get"])
     def tasks(self, request, pk=None):
         """
@@ -112,13 +124,17 @@ class ViewAPI(viewsets.ModelViewSet):
         queryset = Task.prepared.all(prepare_params=view.get_prepare_tasks_params())
         context = {'proxy': bool_from_request(request.GET, 'proxy', True), 'resolve_uri': True}
 
+        # paginated tasks
         self.pagination_class = TaskPagination
         page = self.paginate_queryset(queryset)
         if page is not None:
-            serializer = TaskSerializer(page, many=True, context=context)
+            self.evaluate_predictions(page)
+            serializer = self.task_serializer_class(page, many=True, context=context)
             return self.get_paginated_response(serializer.data)
 
-        serializer = TaskSerializer(queryset, many=True, context=context)
+        # all tasks
+        self.evaluate_predictions(queryset)
+        serializer = self.task_serializer_class(queryset, many=True, context=context)
         return Response(serializer.data)
 
     @swagger_auto_schema(tags=['Data Manager'], methods=["get", "post", "delete", "patch"])
@@ -207,7 +223,7 @@ class TaskAPI(APIView):
             'resolve_uri': True,
             'completed_by': 'full'
         }
-        serializer = TaskSerializer(queryset, many=False, context=context)
+        serializer = self.serializer_class(queryset, many=False, context=context)
         return Response(serializer.data)
 
 
