@@ -6,8 +6,11 @@ import json
 
 from django.db import models, transaction
 from django.utils.translation import gettext_lazy as _
+from django.dispatch import receiver
+from django.db.models.signals import post_save
 from io_storages.base_models import ImportStorage, ImportStorageLink, ExportStorage, ExportStorageLink
-from tasks.serializers import AnnotationSerializer
+from io_storages.serializers import StorageAnnotationSerializer
+from tasks.models import Annotation
 
 logger = logging.getLogger(__name__)
 
@@ -97,13 +100,22 @@ class RedisExportStorage(ExportStorage, RedisStorageMixin):
     def save_annotation(self, annotation):
         client = self.get_client()
         logger.debug(f'Creating new object on {self.__class__.__name__} Storage {self} for annotation {annotation}')
-        ser_annotation = AnnotationSerializer(annotation).data
+        ser_annotation = StorageAnnotationSerializer(annotation).data
         with transaction.atomic():
             # Create export storage link
             link = RedisExportStorageLink.create(annotation, self)
             client.set(link.key, json.dumps(ser_annotation))
 
 
+@receiver(post_save, sender=Annotation)
+def export_annotation_to_s3_storages(sender, instance, **kwargs):
+    project = instance.task.project
+    if hasattr(project, 'io_storages_redisexportstorages'):
+        for storage in project.io_storages_redisexportstorages.all():
+            logger.debug(f'Export {instance} to Redis storage {storage}')
+            storage.save_annotation(instance)
+
+
 class RedisImportStorageLink(ImportStorageLink):
     storage = models.ForeignKey(RedisImportStorage, on_delete=models.CASCADE, related_name='links')
 
