@@ -1,6 +1,7 @@
 """This file and its contents are licensed under the Apache License 2.0. Please see the included NOTICE for copyright information and LICENSE for a copy of the license.
 """
 import drf_yasg.openapi as openapi
+import json
 import logging
 import numpy as np
 import pathlib
@@ -12,6 +13,7 @@ from django.contrib import messages
 from django.core.exceptions import PermissionDenied
 from django.db import IntegrityError
 from django.db.models.fields import DecimalField
+from django.conf import settings
 from drf_yasg.utils import swagger_auto_schema
 from django.db.models import Q, When, Count, Case, OuterRef, Max, Exists, Value, BooleanField
 from rest_framework import generics, status, filters
@@ -21,7 +23,8 @@ from rest_framework.permissions import AllowAny
 from rest_framework.response import Response
 from rest_framework.views import APIView, exception_handler
 
-from core.utils.common import conditional_atomic
+from core.utils.common import conditional_atomic, get_organization_from_request
+from core.label_config import parse_config
 from organizations.models import Organization
 from organizations.permissions import *
 from projects.functions import (generate_unique_title, duplicate_project)
@@ -43,6 +46,7 @@ from core.utils.exceptions import ProjectExistException, LabelStudioDatabaseExce
 from core.utils.io import find_dir, find_file, read_yaml
 
 from data_manager.functions import get_prepared_queryset
+from data_manager.models import View
 
 logger = logging.getLogger(__name__)
 
@@ -102,11 +106,11 @@ class ProjectListAPI(generics.ListCreateAPIView):
     List your projects
 
     Return a list of the projects that you've created.
-    
+
     post:
     Create new project
 
-    Create a labeling project.  
+    Create a labeling project.
     """
     parser_classes = (JSONParser, FormParser, MultiPartParser)
     permission_classes = (IsBusiness, ProjectAPIOrganizationPermission)
@@ -115,7 +119,7 @@ class ProjectListAPI(generics.ListCreateAPIView):
     ordering = ['-created_at']
 
     def get_queryset(self):
-        org_pk = self.request.session.get('organization_pk')
+        org_pk = get_organization_from_request(self.request)
         org = get_object_with_check_and_log(self.request, Organization, pk=org_pk)
         self.check_object_permissions(self.request, org)
         return Project.objects.all()
@@ -127,7 +131,7 @@ class ProjectListAPI(generics.ListCreateAPIView):
 
     def perform_create(self, ser):
         # get organization
-        org_pk = self.request.session.get('organization_pk')
+        org_pk = get_organization_from_request(self.request)
         org = get_object_with_check_and_log(self.request, Organization, pk=org_pk)
         self.check_object_permissions(self.request, org)
 
@@ -190,6 +194,13 @@ class ProjectAPI(APIViewVirtualRedirectMixin,
 
     @swagger_auto_schema(tags=['Projects'], request_body=ProjectSerializer)
     def patch(self, request, *args, **kwargs):
+        project = self.get_object()
+        label_config = self.request.query_params.get('label_config')
+
+        # config changes can break view, so we need to reset them
+        if parse_config(label_config) != parse_config(project.label_config):
+            View.objects.filter(project=project).all().delete()
+
         return super(ProjectAPI, self).patch(request, *args, **kwargs)
 
     def perform_destroy(self, instance):
@@ -366,8 +377,9 @@ class ProjectNextTaskAPI(generics.RetrieveAPIView):
             next_task.set_lock(request.user)
 
         # call machine learning api and format response
-        for ml_backend in project.ml_backends.all():
-            ml_backend.predict_one_task(next_task)
+        if project.show_collab_predictions:
+            for ml_backend in project.ml_backends.all():
+                ml_backend.predict_one_task(next_task)
 
         # serialize task
         context = {'request': request, 'project': project, 'resolve_uri': True,
@@ -397,9 +409,11 @@ class ProjectNextTaskAPI(generics.RetrieveAPIView):
         # support actions api call from actions/next_task.py
         if hasattr(self, 'prepared_tasks'):
             project.prepared_tasks = self.prepared_tasks
+            external_prepared_tasks_used = True
         # get prepared tasks from request params (filters, selected items)
         else:
             project.prepared_tasks = get_prepared_queryset(self.request, project)
+            external_prepared_tasks_used = False
 
         # detect solved and not solved tasks
         user_solved_tasks_array = user.annotations.filter(ground_truth=False).filter(
@@ -415,6 +429,13 @@ class ProjectNextTaskAPI(generics.RetrieveAPIView):
                 raise NotFound(f'There are no tasks remaining to be annotated by the user={user}')
             logger.debug(f'{not_solved_tasks_count} tasks that still need to be annotated for user={user}')
 
+            # ordered by data manager
+            if external_prepared_tasks_used:
+                next_task = not_solved_tasks.first()
+                if not next_task:
+                    raise NotFound('No more tasks found')
+                return self._make_response(next_task, request)
+
             # If current user has already lock one task - return it (without setting the lock again)
             next_task = Task.get_locked_by(user, project)
             if next_task:
@@ -488,14 +509,36 @@ class ProjectLabelConfigValidateAPI(generics.RetrieveAPIView):
     serializer_class = ProjectLabelConfigSerializer
     queryset = Project.objects.all()
 
-    @swagger_auto_schema(tags=['Projects'], operation_summary='Validate a label config for a project.', manual_parameters=[
-        openapi.Parameter(name='label_config', type=openapi.TYPE_STRING, in_=openapi.IN_QUERY,
-                          description='labeling config')])
-    def get(self, request, *args, **kwargs):
+    @swagger_auto_schema(tags=['Projects'], operation_summary='Validate a label config', manual_parameters=[
+                            openapi.Parameter(name='label_config', type=openapi.TYPE_STRING, in_=openapi.IN_QUERY,
+                                              description='labeling config')])
+    def post(self, request, *args, **kwargs):
         project = self.get_object()
-        label_config = self.request.query_params.get('label_config')
+        label_config = self.request.data.get('label_config')
+        if not label_config:
+            raise RestValidationError('Label config is not set or empty')
+
+        # check new config includes meaningful changes
+        config_essential_data_has_changed = self.config_essential_data_has_changed(label_config, project.label_config)
+
         project.validate_config(label_config)
-        return Response(status=status.HTTP_200_OK)
+        return Response({'config_essential_data_has_changed': config_essential_data_has_changed}, status=status.HTTP_200_OK)
+
+    @classmethod
+    def config_essential_data_has_changed(cls, new_config_str, old_config_str):
+        new_config = parse_config(new_config_str)
+        old_config = parse_config(old_config_str)
+
+        for tag, new_info in new_config.items():
+            if tag not in old_config:
+                return True
+            old_info = old_config[tag]
+            if new_info['type'] != old_info['type']:
+                return True
+            if new_info['inputs'] != old_info['inputs']:
+                return True
+            if not set(old_info['labels']).issubset(new_info['labels']):
+                return True
 
 
 class ProjectDuplicateAPI(APIView):
@@ -615,9 +658,12 @@ class TemplateListAPI(generics.ListAPIView):
         configs = []
         for config_file in pathlib.Path(annotation_templates_dir).glob('**/*.yml'):
             config = read_yaml(config_file)
+            if config.get('image', '').startswith('/static') and settings.HOSTNAME:
+                # if hostname set manually, create full image urls
+                config['image'] = settings.HOSTNAME + config['image']
             configs.append(config)
         template_groups_file = find_file(os.path.join('annotation_templates', 'groups.txt'))
-        with open(template_groups_file) as f:
+        with open(template_groups_file, encoding='utf-8') as f:
             groups = f.read().splitlines()
         logger.debug(f'{len(configs)} templates found.')
         return Response({'templates': configs, 'groups': groups})
@@ -630,7 +676,10 @@ class ProjectSampleTask(generics.RetrieveAPIView):
     serializer_class = ProjectSerializer
     swagger_schema = None
 
-    def retrieve(self, request, *args, **kwargs):
-        config = request.GET.get('label_config')
+    def post(self, request, *args, **kwargs):
+        label_config = self.request.data.get('label_config')
+        if not label_config:
+            raise RestValidationError('Label config is not set or empty')
+
         project = self.get_object()
-        return Response({'sample_task': project.get_sample_task(config)}, status=200)
+        return Response({'sample_task': project.get_sample_task(label_config)}, status=200)
