@@ -18,7 +18,7 @@ from users.models import User
 from organizations.models import Organization
 from types import SimpleNamespace
 
-from .utils import create_business, signin, gcs_client_mock, ml_backend_mock, register_ml_backend_mock
+from .utils import create_business, signin, gcs_client_mock, ml_backend_mock, register_ml_backend_mock, azure_client_mock
 
 
 boto3.set_stream_logger('botocore.credentials', logging.DEBUG)
@@ -33,6 +33,13 @@ def aws_credentials():
     os.environ['AWS_SESSION_TOKEN'] = 'testing'
 
 
+@pytest.fixture(autouse=True)
+def azure_credentials():
+    """Mocked Azure credentials"""
+    os.environ['AZURE_BLOB_ACCOUNT_NAME'] = 'testing'
+    os.environ['AZURE_BLOB_ACCOUNT_KEY'] = 'testing'
+
+
 @pytest.fixture(scope='function')
 def s3(aws_credentials):
     with mock_s3():
@@ -47,21 +54,33 @@ def s3_with_images(s3):
     s3://pytest-s3-images/subdir/image1.jpg
     s3://pytest-s3-images/subdir/image2.jpg
     """
-    with mock_s3():
-        bucket_name = 'pytest-s3-images'
-        s3.create_bucket(Bucket=bucket_name)
-        s3.put_object(Bucket=bucket_name, Key='image1.jpg', Body='123')
-        s3.put_object(Bucket=bucket_name, Key='subdir/image1.jpg', Body='456')
-        s3.put_object(Bucket=bucket_name, Key='subdir/image2.jpg', Body='789')
-        yield s3
+    bucket_name = 'pytest-s3-images'
+    s3.create_bucket(Bucket=bucket_name)
+    s3.put_object(Bucket=bucket_name, Key='image1.jpg', Body='123')
+    s3.put_object(Bucket=bucket_name, Key='subdir/image1.jpg', Body='456')
+    s3.put_object(Bucket=bucket_name, Key='subdir/image2.jpg', Body='789')
+    yield s3
+
+
+@pytest.fixture(autouse=True)
+def s3_with_jsons(s3):
+    """
+    Bucket structure:
+    s3://pytest-s3-images/image1.jpg
+    s3://pytest-s3-images/subdir/image1.jpg
+    s3://pytest-s3-images/subdir/image2.jpg
+    """
+    bucket_name = 'pytest-s3-jsons'
+    s3.create_bucket(Bucket=bucket_name)
+    s3.put_object(Bucket=bucket_name, Key='test.json', Body=json.dumps({'image_url': 'http://ggg.com/image.jpg'}))
+    yield s3
 
 
 @pytest.fixture(autouse=True)
 def s3_export_bucket(s3):
-    with mock_s3():
-        bucket_name = 'pytest-export-s3-bucket'
-        s3.create_bucket(Bucket=bucket_name)
-        yield s3
+    bucket_name = 'pytest-export-s3-bucket'
+    s3.create_bucket(Bucket=bucket_name)
+    yield s3
 
 
 @pytest.fixture(autouse=True)
@@ -70,6 +89,12 @@ def gcs_client():
         yield
 
 
+@pytest.fixture(autouse=True)
+def azure_client():
+    with azure_client_mock():
+        yield
+
+
 @pytest.fixture(autouse=True)
 def ml_backend():
     with ml_backend_mock() as m:
